![PyPI - Python Version](https://img.shields.io/pypi/pyversions/transferboost)
![PyPI](https://img.shields.io/pypi/v/transferboost)


# TransferBoost (transferboost)

Tooling for transfer learning with Boosting Models

## Installing transferboost

Install `transferboost` directly from pip

```shell
pip3 install transferboost
```

## Documentation

The documentation can be found [here](https://sbjelogr.github.io/TransferBoost).

## Supported models

`transferboost` supports the transfer learning for the following models:<br>
- XGBClassifier
- LGBMClassifier
